@@ -3,9 +3,10 @@ function(x){
   ## Coerces a list with vectors of different length into a data.frame
   ## fills the shorter vectors with NA
   ##
-  ## Author: Thomas Unternaehrer
-  ## Version 18.1.05
-  if (!is.list(x)) stop("'x' must be of type list")
+  ## Authors: Thomas Unternaehrer, Ren Locher
+  ## Version 29.09.05
+  if (!is.list(x)) stop("'x' must be of type list\n\n")
+  if (min(sapply(x,length)) == 0) stop("NULL elements in list not allowed\n\n")
   return(sapply(x, function(y) {length(y) <- max(sapply(x,length));y}))
 }
 
